========
Numerics
========

Sub-commands to support the numerics components


.. autosummary::
    :nosignatures:
    :toctree: _generated/

    rompy_swan.subcomponents.numerics.BSBT
    rompy_swan.subcomponents.numerics.GSE
    rompy_swan.subcomponents.numerics.STAT
    rompy_swan.subcomponents.numerics.NONSTAT
    rompy_swan.subcomponents.numerics.STOPC
    rompy_swan.subcomponents.numerics.ACCUR
    rompy_swan.subcomponents.numerics.DIRIMPL
    rompy_swan.subcomponents.numerics.SIGIMPL
    rompy_swan.subcomponents.numerics.CTHETA
    rompy_swan.subcomponents.numerics.CSIGMA
    rompy_swan.subcomponents.numerics.SETUP